@@ -1,8 +1,14 @@
+/*
+* (C) 2009-2010 Jack Lloyd
+*
+* Distributed under the terms of the Botan license
+*/
+
 #include <botan/pkcs8.h>
 #include <botan/mem_ops.h>
-#include <botan/look_pk.h>
-#include <botan/libstate.h>
 #include <botan/parsing.h>
+#include <botan/oids.h>
+#include <map>
 
 #if defined(BOTAN_HAS_RSA)
   #include <botan/rsa.h>
@@ -39,8 +45,12 @@
   #include <botan/ecdsa.h>
 #endif
 
-#if defined(BOTAN_HAS_ECKAEG)
-  #include <botan/eckaeg.h>
+#if defined(BOTAN_HAS_ECDH)
+  #include <botan/ecdh.h>
+#endif
+
+#if defined(BOTAN_HAS_GOST_34_10_2001)
+  #include <botan/gost_3410.h>
 #endif
 
 using namespace Botan;
@@ -53,9 +63,33 @@ using namespace Botan;
 #include <fstream>
 #include <string>
 #include <memory>
+#include <set>
 
 namespace {
 
+const char* ec_domains[] = {
+   "secp160r2",
+   "secp192r1",
+   "secp224r1",
+   "secp256r1",
+   "secp384r1",
+   "secp521r1",
+   0
+};
+
+class Benchmark_Report
+   {
+   public:
+      void report(const std::string& name, Timer timer)
+         {
+         std::cout << name << " " << timer << std::endl;
+         data[name].insert(timer);
+         }
+
+   private:
+      std::map<std::string, std::set<Timer> > data;
+   };
+
 void benchmark_enc_dec(PK_Encryptor& enc, PK_Decryptor& dec,
                        Timer& enc_timer, Timer& dec_timer,
                        RandomNumberGenerator& rng,
@@ -67,7 +101,7 @@ void benchmark_enc_dec(PK_Encryptor& enc, PK_Decryptor& dec,
       {
       if(enc_timer.seconds() < seconds || ciphertext.size() == 0)
          {
-         plaintext.create(enc.maximum_input_size());
+         plaintext.resize(enc.maximum_input_size());
 
          // Ensure for Raw, etc, it stays large
          if((i % 100) == 0)
@@ -108,7 +142,7 @@ void benchmark_sig_ver(PK_Verifier& ver, PK_Signer& sig,
          {
          if((i % 100) == 0)
             {
-            message.create(48);
+            message.resize(48);
             rng.randomize(message.begin(), message.size());
             }
 
@@ -128,7 +162,7 @@ void benchmark_sig_ver(PK_Verifier& ver, PK_Signer& sig,
 
          if((i % 100) == 0)
             {
-            sig_random.create(signature.size());
+            sig_random.resize(signature.size());
             rng.randomize(sig_random, sig_random.size());
 
             verify_timer.start();
@@ -155,7 +189,7 @@ void benchmark_rsa(RandomNumberGenerator& rng,
                    Benchmark_Report& report)
    {
 
-   size_t keylens[] = { 512, 1024, 2048, 4096, 6144, 8192, 0 };
+   size_t keylens[] = { 1024, 2048, 4096, 6144, 0 };
 
    for(size_t i = 0; keylens[i]; ++i)
       {
@@ -191,13 +225,16 @@ void benchmark_rsa(RandomNumberGenerator& rng,
          while(verify_timer.seconds() < seconds ||
                sig_timer.seconds() < seconds)
             {
-            std::auto_ptr<PK_Encryptor> enc(get_pk_encryptor(key, enc_padding));
-            std::auto_ptr<PK_Decryptor> dec(get_pk_decryptor(key, enc_padding));
-            benchmark_enc_dec(*enc, *dec, enc_timer, dec_timer, rng, 10000, seconds);
+            PK_Encryptor_EME enc(key, enc_padding);
+            PK_Decryptor_EME dec(key, enc_padding);
 
-            std::auto_ptr<PK_Signer> sig(get_pk_signer(key, sig_padding));
-            std::auto_ptr<PK_Verifier> ver(get_pk_verifier(key, sig_padding));
-            benchmark_sig_ver(*ver, *sig, verify_timer,
+            benchmark_enc_dec(enc, dec, enc_timer, dec_timer,
+                              rng, 10000, seconds);
+
+            PK_Signer sig(key, sig_padding);
+            PK_Verifier ver(key, sig_padding);
+
+            benchmark_sig_ver(ver, sig, verify_timer,
                               sig_timer, rng, 10000, seconds);
             }
 
@@ -227,7 +264,7 @@ void benchmark_rw(RandomNumberGenerator& rng,
                   Benchmark_Report& report)
    {
 
-   const u32bit keylens[] = { 512, 1024, 2048, 4096, 6144, 8192, 0 };
+   const u32bit keylens[] = { 1024, 2048, 4096, 6144, 0 };
 
    for(size_t j = 0; keylens[j]; j++)
       {
@@ -246,10 +283,11 @@ void benchmark_rw(RandomNumberGenerator& rng,
          RW_PrivateKey key(rng, keylen);
          keygen_timer.stop();
 
-         std::auto_ptr<PK_Signer> sig(get_pk_signer(key, padding));
-         std::auto_ptr<PK_Verifier> ver(get_pk_verifier(key, padding));
+         PK_Signer sig(key, padding);
+         PK_Verifier ver(key, padding);
 
-         benchmark_sig_ver(*ver, *sig, verify_timer, sig_timer, rng, 10000, seconds);
+         benchmark_sig_ver(ver, sig, verify_timer, sig_timer,
+                           rng, 10000, seconds);
          }
 
       const std::string nm = "RW-" + to_string(keylen);
@@ -266,23 +304,15 @@ void benchmark_ecdsa(RandomNumberGenerator& rng,
                      double seconds,
                      Benchmark_Report& report)
    {
-   const char* domains[] = { "1.3.132.0.6", // secp112r1
-                             "1.3.132.0.28", // secp128r1
-                             "1.3.132.0.30", // secp160r2
-                             "1.3.132.0.33", // secp224r1
-                             "1.3.132.0.34", // secp384r1
-                             "1.3.132.0.35", // secp512r1
-                             NULL };
-
-   for(size_t j = 0; domains[j]; j++)
+   for(size_t j = 0; ec_domains[j]; j++)
       {
-      EC_Domain_Params params = get_EC_Dom_Pars_by_oid(domains[j]);
+      EC_Domain_Params params(OIDS::lookup(ec_domains[j]));
 
       u32bit pbits = params.get_curve().get_p().bits();
 
       u32bit hashbits = pbits;
 
-      if(hashbits < 160)
+      if(hashbits <= 192)
          hashbits = 160;
       if(hashbits == 521)
          hashbits = 512;
@@ -300,10 +330,10 @@ void benchmark_ecdsa(RandomNumberGenerator& rng,
          ECDSA_PrivateKey key(rng, params);
          keygen_timer.stop();
 
-         std::auto_ptr<PK_Signer> sig(get_pk_signer(key, padding));
-         std::auto_ptr<PK_Verifier> ver(get_pk_verifier(key, padding));
+         PK_Signer sig(key, padding, IEEE_1363, DISABLE_FAULT_PROTECTION);
+         PK_Verifier ver(key, padding);
 
-         benchmark_sig_ver(*ver, *sig, verify_timer,
+         benchmark_sig_ver(ver, sig, verify_timer,
                            sig_timer, rng, 1000, seconds);
          }
 
@@ -317,23 +347,64 @@ void benchmark_ecdsa(RandomNumberGenerator& rng,
 
 #endif
 
-#if defined(BOTAN_HAS_ECKAEG)
+#if defined(BOTAN_HAS_GOST_34_10_2001)
 
-void benchmark_eckaeg(RandomNumberGenerator& rng,
-                      double seconds,
-                      Benchmark_Report& report)
+void benchmark_gost_3410(RandomNumberGenerator& rng,
+                         double seconds,
+                         Benchmark_Report& report)
    {
-   const char* domains[] = { "1.3.132.0.6", // secp112r1
-                             "1.3.132.0.28", // secp128r1
-                             "1.3.132.0.30", // secp160r2
-                             "1.3.132.0.33", // secp224r1
-                             "1.3.132.0.34", // secp384r1
-                             "1.3.132.0.35", // secp512r1
-                             NULL };
-
-   for(size_t j = 0; domains[j]; j++)
+   for(size_t j = 0; ec_domains[j]; j++)
       {
-      EC_Domain_Params params = get_EC_Dom_Pars_by_oid(domains[j]);
+      EC_Domain_Params params(OIDS::lookup(ec_domains[j]));
+
+      u32bit pbits = params.get_curve().get_p().bits();
+
+      u32bit hashbits = pbits;
+
+      if(hashbits <= 192)
+         hashbits = 160;
+      if(hashbits == 521)
+         hashbits = 512;
+
+      const std::string padding = "EMSA1(SHA-" + to_string(hashbits) + ")";
+
+      Timer keygen_timer("keygen");
+      Timer verify_timer(padding + " verify");
+      Timer sig_timer(padding + " signature");
+
+      while(verify_timer.seconds() < seconds ||
+            sig_timer.seconds() < seconds)
+         {
+         keygen_timer.start();
+         GOST_3410_PrivateKey key(rng, params);
+         keygen_timer.stop();
+
+         PK_Signer sig(key, padding, IEEE_1363, DISABLE_FAULT_PROTECTION);
+         PK_Verifier ver(key, padding);
+
+         benchmark_sig_ver(ver, sig, verify_timer,
+                           sig_timer, rng, 1000, seconds);
+         }
+
+      const std::string nm = "GOST-34.10-" + to_string(pbits);
+
+      report.report(nm, keygen_timer);
+      report.report(nm, verify_timer);
+      report.report(nm, sig_timer);
+      }
+   }
+
+#endif
+
+#if defined(BOTAN_HAS_ECDH)
+
+void benchmark_ecdh(RandomNumberGenerator& rng,
+                    double seconds,
+                    Benchmark_Report& report)
+   {
+   for(size_t j = 0; ec_domains[j]; j++)
+      {
+      EC_Domain_Params params(OIDS::lookup(ec_domains[j]));
 
       u32bit pbits = params.get_curve().get_p().bits();
 
@@ -343,17 +414,17 @@ void benchmark_eckaeg(RandomNumberGenerator& rng,
       while(kex_timer.seconds() < seconds)
          {
          keygen_timer.start();
-         ECKAEG_PrivateKey eckaeg1(rng, params);
+         ECDH_PrivateKey ecdh1(rng, params);
          keygen_timer.stop();
 
          keygen_timer.start();
-         ECKAEG_PrivateKey eckaeg2(rng, params);
+         ECDH_PrivateKey ecdh2(rng, params);
          keygen_timer.stop();
 
-         ECKAEG_PublicKey pub1(eckaeg1);
-         ECKAEG_PublicKey pub2(eckaeg2);
+         PK_Key_Agreement ka1(ecdh1, "KDF2(SHA-1)");
+         PK_Key_Agreement ka2(ecdh2, "KDF2(SHA-1)");
 
-         SecureVector<byte> secret1, secret2;
+         SymmetricKey secret1, secret2;
 
          for(u32bit i = 0; i != 1000; ++i)
             {
@@ -361,19 +432,19 @@ void benchmark_eckaeg(RandomNumberGenerator& rng,
                break;
 
             kex_timer.start();
-            secret1 = eckaeg1.derive_key(pub2);
+            secret1 = ka1.derive_key(32, ecdh2.public_value());
             kex_timer.stop();
 
             kex_timer.start();
-            secret2 = eckaeg2.derive_key(pub1);
+            secret2 = ka2.derive_key(32, ecdh1.public_value());
             kex_timer.stop();
 
             if(secret1 != secret2)
-               std::cerr << "ECKAEG secrets did not match, bug in the library!?!\n";
+               std::cerr << "ECDH secrets did not match\n";
             }
          }
 
-      const std::string nm = "ECKAEG-" + to_string(pbits);
+      const std::string nm = "ECDH-" + to_string(pbits);
       report.report(nm, keygen_timer);
       report.report(nm, kex_timer);
       }
@@ -387,14 +458,12 @@ void benchmark_dsa_nr(RandomNumberGenerator& rng,
                       Benchmark_Report& report)
    {
 #if defined(BOTAN_HAS_NYBERG_RUEPPEL) || defined(BOTAN_HAS_DSA)
-   const char* domains[] = { "dsa/jce/512",
-                             "dsa/jce/768",
-                             "dsa/jce/1024",
+   const char* domains[] = { "dsa/jce/1024",
                              "dsa/botan/2048",
                              "dsa/botan/3072",
                              NULL };
 
-   const std::string algo_name = PRIV_KEY_TYPE().algo_name();
+   std::string algo_name;
 
    for(size_t j = 0; domains[j]; j++)
       {
@@ -414,12 +483,13 @@ void benchmark_dsa_nr(RandomNumberGenerator& rng,
 
          keygen_timer.start();
          PRIV_KEY_TYPE key(rng, group);
+         algo_name = key.algo_name();
          keygen_timer.stop();
 
-         std::auto_ptr<PK_Signer> sig(get_pk_signer(key, padding));
-         std::auto_ptr<PK_Verifier> ver(get_pk_verifier(key, padding));
+         PK_Signer sig(key, padding, IEEE_1363, DISABLE_FAULT_PROTECTION);
+         PK_Verifier ver(key, padding);
 
-         benchmark_sig_ver(*ver, *sig, verify_timer,
+         benchmark_sig_ver(ver, sig, verify_timer,
                            sig_timer, rng, 1000, seconds);
          }
 
@@ -436,8 +506,7 @@ void benchmark_dh(RandomNumberGenerator& rng,
                   double seconds,
                   Benchmark_Report& report)
    {
-   const char* domains[] = { "modp/ietf/768",
-                             "modp/ietf/1024",
+   const char* domains[] = { "modp/ietf/1024",
                              "modp/ietf/2048",
                              "modp/ietf/3072",
                              "modp/ietf/4096",
@@ -462,10 +531,10 @@ void benchmark_dh(RandomNumberGenerator& rng,
          DH_PrivateKey dh2(rng, group);
          keygen_timer.stop();
 
-         DH_PublicKey pub1(dh1);
-         DH_PublicKey pub2(dh2);
+         PK_Key_Agreement ka1(dh1, "KDF2(SHA-1)");
+         PK_Key_Agreement ka2(dh2, "KDF2(SHA-1)");
 
-         SecureVector<byte> secret1, secret2;
+         SymmetricKey secret1, secret2;
 
          for(u32bit i = 0; i != 1000; ++i)
             {
@@ -473,15 +542,15 @@ void benchmark_dh(RandomNumberGenerator& rng,
                break;
 
             kex_timer.start();
-            secret1 = dh1.derive_key(pub2);
+            secret1 = ka1.derive_key(32, dh2.public_value());
             kex_timer.stop();
 
             kex_timer.start();
-            secret2 = dh2.derive_key(pub1);
+            secret2 = ka2.derive_key(32, dh1.public_value());
             kex_timer.stop();
 
             if(secret1 != secret2)
-               std::cerr << "DH secrets did not match, bug in the library!?!\n";
+               std::cerr << "DH secrets did not match\n";
             }
          }
 
@@ -586,10 +655,11 @@ void benchmark_elg(RandomNumberGenerator& rng,
          ElGamal_PrivateKey key(rng, group);
          keygen_timer.stop();
 
-         std::auto_ptr<PK_Decryptor> dec(get_pk_decryptor(key, padding));
-         std::auto_ptr<PK_Encryptor> enc(get_pk_encryptor(key, padding));
+         PK_Decryptor_EME dec(key, padding);
+         PK_Encryptor_EME enc(key, padding);
 
-         benchmark_enc_dec(*enc, *dec, enc_timer, dec_timer, rng, 1000, seconds);
+         benchmark_enc_dec(enc, dec, enc_timer, dec_timer,
+                           rng, 1000, seconds);
          }
 
       const std::string nm = algo_name + "-" + to_string(pbits);
@@ -603,7 +673,7 @@ void benchmark_elg(RandomNumberGenerator& rng,
 }
 
 void bench_pk(RandomNumberGenerator& rng,
-              const std::string& algo, bool, double seconds)
+              const std::string& algo, double seconds)
    {
    /*
      There is some strangeness going on here. It looks like algorithms
@@ -631,8 +701,6 @@ void bench_pk(RandomNumberGenerator& rng,
      there is no way to encode a RW key into a PKCS #8 structure).
    */
 
-   global_state().set_option("pk/test/private_gen", "basic");
-
    Benchmark_Report report;
 
 #if defined(BOTAN_HAS_RSA)
@@ -650,9 +718,14 @@ void bench_pk(RandomNumberGenerator& rng,
       benchmark_ecdsa(rng, seconds, report);
 #endif
 
-#if defined(BOTAN_HAS_ECKAEG)
-   if(algo == "All" || algo == "ECKAEG")
-      benchmark_eckaeg(rng, seconds, report);
+#if defined(BOTAN_HAS_ECDH)
+   if(algo == "All" || algo == "ECDH")
+      benchmark_ecdh(rng, seconds, report);
+#endif
+
+#if defined(BOTAN_HAS_GOST_34_10_2001)
+   if(algo == "All" || algo == "GOST-34.10")
+      benchmark_gost_3410(rng, seconds, report);
 #endif
 
 #if defined(BOTAN_HAS_DIFFIE_HELLMAN)
@@ -675,6 +748,8 @@ void bench_pk(RandomNumberGenerator& rng,
       benchmark_dsa_nr<NR_PrivateKey>(rng, seconds, report);
 #endif
 
+#if defined(BOTAN_HAS_RW)
    if(algo == "All" || algo == "RW")
       benchmark_rw(rng, seconds, report);
+#endif
    }
