@@ -20,15 +20,16 @@ namespace Botan {
 class BOTAN_DLL Lion : public BlockCipher
    {
    public:
-      void clear() throw();
+      void encrypt_n(const byte in[], byte out[], u32bit blocks) const;
+      void decrypt_n(const byte in[], byte out[], u32bit blocks) const;
+
+      void clear();
       std::string name() const;
       BlockCipher* clone() const;
 
       Lion(HashFunction*, StreamCipher*, u32bit);
       ~Lion() { delete hash; delete cipher; }
    private:
-      void enc(const byte[], byte[]) const;
-      void dec(const byte[], byte[]) const;
       void key_schedule(const byte[], u32bit);
 
       const u32bit LEFT_SIZE, RIGHT_SIZE;
