@@ -18,15 +18,17 @@ namespace Botan {
 class BOTAN_DLL TEA : public BlockCipher
    {
    public:
-      void clear() throw() { K.clear(); }
+      void encrypt_n(const byte in[], byte out[], u32bit blocks) const;
+      void decrypt_n(const byte in[], byte out[], u32bit blocks) const;
+
+      void clear() { K.clear(); }
       std::string name() const { return "TEA"; }
       BlockCipher* clone() const { return new TEA; }
+
       TEA() : BlockCipher(8, 16) {}
    private:
-      void enc(const byte[], byte[]) const;
-      void dec(const byte[], byte[]) const;
       void key_schedule(const byte[], u32bit);
-      SecureBuffer<u32bit, 4> K;
+      SecureVector<u32bit, 4> K;
    };
 
 }
