@@ -5,7 +5,7 @@
 * Distributed under the terms of the Botan license
 */
 
-#include <botan/def_eng.h>
+#include <botan/internal/default_engine.h>
 #include <botan/scan_name.h>
 #include <botan/algo_factory.h>
 #include <memory>
@@ -22,6 +22,10 @@
   #include <botan/crc32.h>
 #endif
 
+#if defined(BOTAN_HAS_BMW_512)
+  #include <botan/bmw_512.h>
+#endif
+
 #if defined(BOTAN_HAS_FORK_256)
   #include <botan/fork256.h>
 #endif
@@ -103,6 +107,11 @@ Default_Engine::find_hash(const SCAN_Name& request,
       return new CRC32;
 #endif
 
+#if defined(BOTAN_HAS_BMW_512)
+   if(request.algo_name() == "BMW-512")
+      return new BMW_512;
+#endif
+
 #if defined(BOTAN_HAS_FORK_256)
    if(request.algo_name() == "FORK-256")
       return new FORK_256;
