@@ -19,20 +19,23 @@ namespace Botan {
 class BOTAN_DLL ARC4 : public StreamCipher
    {
    public:
-      void clear() throw();
+      void cipher(const byte in[], byte out[], u32bit length);
+
+      void clear();
       std::string name() const;
+
       StreamCipher* clone() const { return new ARC4(SKIP); }
+
       ARC4(u32bit = 0);
       ~ARC4() { clear(); }
    private:
-      void cipher(const byte[], byte[], u32bit);
       void key_schedule(const byte[], u32bit);
       void generate();
 
       const u32bit SKIP;
 
-      SecureBuffer<byte, DEFAULT_BUFFERSIZE> buffer;
-      SecureBuffer<u32bit, 256> state;
+      SecureVector<byte, DEFAULT_BUFFERSIZE> buffer;
+      SecureVector<u32bit, 256> state;
       u32bit X, Y, position;
    };
 
