@@ -23,38 +23,19 @@ class BOTAN_DLL SymmetricAlgorithm
 
       /**
       * The maximum allowed key length.
-      * @deprecated use maximum_keylength()
       */
       const u32bit MAXIMUM_KEYLENGTH;
 
       /**
       * The minimal allowed key length.
-      * @deprecated use minimum_keylength()
       */
       const u32bit MINIMUM_KEYLENGTH;
 
       /**
       * A valid keylength is a multiple of this value.
-      * @deprecated
       */
       const u32bit KEYLENGTH_MULTIPLE;
 
-      /**
-      * @return minimum allowed key length
-      */
-      size_t maximum_keylength() const
-         {
-         return MAXIMUM_KEYLENGTH;
-         }
-
-      /**
-      * @return maxmium allowed key length
-      */
-      size_t minimum_keylength() const
-         {
-         return MINIMUM_KEYLENGTH;
-         }
-
       /**
       * The name of the algorithm.
       * @return the name of the algorithm
@@ -65,7 +46,7 @@ class BOTAN_DLL SymmetricAlgorithm
       * Set the symmetric key of this object.
       * @param key the SymmetricKey to be set.
       */
-      void set_key(const SymmetricKey& key) throw(Invalid_Key_Length)
+      void set_key(const SymmetricKey& key)
          { set_key(key.begin(), key.length()); }
 
       /**
@@ -73,7 +54,7 @@ class BOTAN_DLL SymmetricAlgorithm
       * @param key the to be set as a byte array.
       * @param the length of the byte array.
       */
-      void set_key(const byte key[], u32bit length) throw(Invalid_Key_Length)
+      void set_key(const byte key[], u32bit length)
          {
          if(!valid_keylength(length))
             throw Invalid_Key_Length(name(), length);
